<p align="center">
<img src="https://raw.githubusercontent.com/CoLRev-Ecosystem/colrev/main/docs/figures/logo_small.png" width="400">
</p>

# Collaborative Literature Reviews (CoLRev)

[![GitHub release](https://img.shields.io/github/v/release/CoLRev-Ecosystem/colrev.svg)](https://github.com/CoLRev-Ecosystem/colrev/releases/)
![PyPI](https://img.shields.io/pypi/v/colrev)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/colrev)
[![](https://img.shields.io/badge/-documentation-green)](https://colrev.readthedocs.io/)
[![License](https://img.shields.io/github/license/CoLRev-Ecosystem/colrev.svg)](https://github.com/CoLRev-Ecosystem/colrev/releases/)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/CoLRev-Ecosystem/colrev/tox_workflow.yml)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/CoLRev-Ecosystem/colrev/main.svg)](https://results.pre-commit.ci/latest/github/CoLRev-Ecosystem/colrev/main)
![Coverage](coverage.svg)
![GitHub last commit](https://img.shields.io/github/last-commit/CoLRev-Ecosystem/colrev)

CoLRev is an open-source environment for collaborative reviews.
To make major improvements in terms of efficiency and trustworthiness and to automatically augment reviews with community-curated content, CoLRev advances the design of review technology at the intersection of methods, engineering, cognition, and community building.
Compared to other environments, the following features stand out:

- an **extensible and open platform** based on shared data and process standards
- builds on **git** and its transparent collaboration model for the entire literature review process
- offers a **self-explanatory, fault-tolerant, and configurable** user workflow
- implements a granular **data provenance** model and **robust identification** schemes
- provides **end-to-end process support** and allows you to **plug in state-of-the-art tools**
- enables **typological and methodological pluralism** throughout the process
- operates a **built-in model for content curation** and reuse

See the [documentation](https://colrev.readthedocs.io/en/latest/) for more details.

## Contributing, changes, and releases

Contributions, code and features are always welcome

- See [contributing guidelines](CONTRIBUTING.md), [help page](docs/build/user_resources/help.html), and [github repository](https://github.com/CoLRev-Ecosystem/colrev).
- Bug reports or feedback? Please use the [issue tracker](https://github.com/CoLRev-Ecosystem/colrev/issues) and let us know.
- To get your work included, fork the repository, implement your changes, and create a [pull request](https://docs.github.com/en/github/collaborating-with-issues-and-pull-requests/proposing-changes-to-your-work-with-pull-requests/about-pull-requests).

For further information, see [changes](CHANGELOG.md) and [releases](https://github.com/CoLRev-Ecosystem/colrev/releases).

## License

This project is distributed under the [MIT License](LICENSE) the documentation is distributed under the [CC-0](https://creativecommons.org/publicdomain/zero/1.0/) license.
If you contribute to the project, you agree to share your contribution following these licenses.

## Citing CoLRev

Please [cite](docs/_static/colrev_citation.bib) the project as follows:

Wagner, G. and Prester, J. (2023) CoLRev - An open-source environment for Collaborative Literature Reviews. Available at https://github.com/CoLRev-Ecosystem/colrev.
